#!/bin/bash
#
#PBS -N job_2

#PBS -q 

#PBS -l nodes=1:ppn=4

#PBS -l walltime=04:00:00

#PBS -j oe
#PBS -o localhost:/home/jillian/projects/perl/HPC-Runner-PBS/example/logs/pbs_logs_2015_11_12T10_35_28/job_2.log

#PBS -l mem=24GB





    
module load module1
    


cd /home/jillian/projects/perl/HPC-Runner-PBS/example
mcerunner.pl --procs 4 --infile /home/jillian/projects/perl/HPC-Runner-PBS/example/logs/job_2.in --outdir /home/jillian/projects/perl/HPC-Runner-PBS/example/logs --logname job_2
